Module metadata

Module metadata 

Structs

Metadata
Metadata wrapper around the runtime metadata. Offers some extra features, such as direct pallets, events and error access.
PalletMetadata
Metadata for a specific pallet.
RuntimeApiMetadata
Metadata for the available runtime APIs.

Enums

MetadataConversionError
MetadataError
Metadata error originated from inspecting the internal representation of the runtime metadata.

Functions

v14_to_v15